PFDC(1)                               pce                              PFDC(1)



NAME
       pfdc - convert and modify PFDC floppy disk image files


SYNOPSIS
       pfdc [options] [input-file] [options] [output-file]


DESCRIPTION
       pfdc(1) is used to modify and convert PFDC floppy disk images files.


OPTIONS
       -a, --alternate alt1[-alt2]
              Select a range of alternate sectors.

       -c, --cylinder cyl1[-cyl2]
              Select a range of cylinders.

       -e, --edit what val
              For all selected sectors, set sector attribute what to val.  For
              boolean attributes, a value of 0 disables the attribute and  any
              other value enables it.  Recognized attributes are:

              crc-id The ID field contains a CRC error.

              crc-data
                     The data field contains a CRC error.

              del-dam
                     The sector has a deleted data address mark.

              data-rate
                     The data rate in bits per second.

              fm     The sector uses FM encoding.

              mfm    The sector uses MFM encoding.

              size   The sector size in bytes.

              c      The cylinder number in the sector ID.

              h      The head number in the sector ID.

              s      The sector number in the sector ID.

       -f, --info
              Print  information  about  the  current  image or the next image
              loaded.

       -F, --filler val
              Set the fill byte to val. The fill byte is used when sectors are
              created or enlarged.

       -h, --head head1[-head2]
              Select a range of heads.

       -i, --input filename
              Load an image from filename.

       -I, --input-format format
              Set the input file format to format.  Valid formats are:

              pfdc   The native PFDC file format.

              ana    The anadisk dump format.

              imd    The ImageDisk file format.

              tc     Transcopy  dump format. Support for this format is highly
                     experimental.  This format is only available as an  input
                     format.

              td0    The  teledisk  file  format.  Only  files  that don't use
                     advanced compression are supported.

              raw    A raw sector dump.

       -l, --list-tracks
              List all tracks in the  current  image  or  in  the  next  image
              loaded.

       -L, --list-sectors
              List  all  sectors  in  the  current  image or in the next image
              loaded.

       -m, --merge filename
              Load an image from filename and merge it with the current image.
              Sectors  that are identical are discarded. Sectors that exist in
              only one image are retained. Sectors that exist in both  images,
              but differ, are added as alternate sectors.

       -n, --new size
              Create a new image of size size KiB.

       -o, --output filename
              Set the output file name. Before exiting, the current image will
              be written to this file.

       -O, --output-format format
              Set the output file format to format. See the -I  option  for  a
              list of valid formats.

       -p, --operation name [arg...]
              Perform an operation on the current image. Valid operations are:

              comment-add text
                     Add text to the image comment.

              comment-load filename
                     Load the image comment from file filename.

              comment-print
                     Print the current image comment.

              comment-save filename
                     Save the current image comment to filename.

              comment-set text
                     Set the image comment to text.

              delete Delete all selected sectors.

              info   Print information about the current image (same as -f).

              load filename"
                     Load  the contents of all selected sectors from filename.
                     The contents of the sectors are  read  sequentially  from
                     the file.

              new    Create  all  selected  sectors,  if  they  do not already
                     exist.

              reorder s1,s2,s3,...
                     Reorder the sectors on all selected tracks. Sectors  that
                     are  not  mentioned in the parameter are moved to the end
                     of the track.

              rotate first
                     Rotate the sectors on all selected tracks such that first
                     is the first sector on the track. If first does not exist
                     on a track, the next higher sector will be rotated to the
                     start of the track.

              save filename
                     Save  all  selected  sectors to filename. The contents of
                     the sectors are written sequentially to the file.

       -r, --record cyl1[-cyl2] head1[-head2] sect1[-sect2]
              Select sectors. This is the same as using  the  -c,  -h  and  -s
              options seperately.

       -s, --sector sect1[-sect2]
              Select a range of logical sectors.

       -S, --real-sectors sect1[-sect2]
              Select a range of physical sectors.

       -v, --verbose
              Enable verbose operation.

       --help Print usage information.

       --version
              Print version information.


EXAMPLES
       Convert an ImageDisk file to a PFDC file:

              $ pfdc source.imd dest.pfdc

       Get image information:

              $ pfdc -f image.pfdc

       Add sectors 10 and 11 to all tracks on side 0:

              $ pfdc -i source.pfdc -r all 0 10-11 -p new -o dest.pfdc

       Mark the first sector in the image as having a bad data CRC:

              $ pfdc -i source.pfdc -r 0 0 1 -e crc-data 1 -o dest.pfdc

       Set the image comment:

              $ pfdc -i source.pfdc -p comment-set "Test image" -o dest.pfdc


SEE ALSO
       pce-ibmpc(1), pce-macplus(1), pce-img(1)


AUTHOR
       Hampa Hug <hampa@hampa.ch>



HH                                2010-08-22                           PFDC(1)
